DSSessionManager class

Manages user sessions for Cognito authentication

Constructors

DSSessionManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllSessions() Future<void>
Clears all sessions
clearSession(String userId) Future<void>
Clears user session
getSession(String userId) Future<Map<String, dynamic>?>
Retrieves user session data
isSessionValid(String userId) Future<bool>
Checks if session is valid
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshSession(String userId) Future<void>
Updates session timestamp
storeSession(String userId, String accessToken) Future<void>
Stores user session data
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited