DSTokenManager class

Manages JWT tokens for Cognito authentication

Constructors

DSTokenManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeToken(String token) Map<String, dynamic>
Decodes JWT token payload
getUserIdFromToken(String token) String?
Extracts user ID from token
isTokenExpired(String token) bool
Checks if token is expired
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifyToken(String token) Future<bool>
Validates and verifies a JWT token

Operators

operator ==(Object other) bool
The equality operator.
inherited